==> open-xchange-usm_7.0.0.orig.tar.bz2: open-xchange-usm-7.0.0/com.openexchange.usm.contenttypes.util/src/com/openexchange/usm/contenttypes/attachments/PIMAttachmentErrorCodes.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.contenttypes.attachments;

public interface PIMAttachmentErrorCodes {

	
	int ID_NOT_EXISTING = 0x480000;

	int INVALID_OX_RESULT_1 = 0x480001;
	int INVALID_OX_RESULT_2 = 0x480002;
	int INVALID_OX_RESULT_3 = 0x480003;
	int INVALID_OX_RESULT_4 = 0x480004;
	int INVALID_OX_RESULT_5 = 0x480005;
	int INVALID_OX_RESULT_6 = 0x480006;
	
	int CAN_NOT_CREATE_REQUEST_BODY = 0x480007;
	
	int ERROR_ON_STORE_RESOURCE_1 = 0x480008;
	int ERROR_ON_STORE_RESOURCE_2 = 0x480009;
}

==> open-xchange-usm_7.6.2.orig.tar.bz2: open-xchange-usm-7.6.2/com.openexchange.usm.contenttypes.util/src/com/openexchange/usm/contenttypes/attachments/PIMAttachmentErrorCodes.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.contenttypes.attachments;

public interface PIMAttachmentErrorCodes {

	
	int ID_NOT_EXISTING = 0x480000;

	int INVALID_OX_RESULT_1 = 0x480001;
	int INVALID_OX_RESULT_2 = 0x480002;
	int INVALID_OX_RESULT_3 = 0x480003;
	int INVALID_OX_RESULT_4 = 0x480004;
	int INVALID_OX_RESULT_5 = 0x480005;
	int INVALID_OX_RESULT_6 = 0x480006;
	
	int CAN_NOT_CREATE_REQUEST_BODY = 0x480007;
	
	int ERROR_ON_STORE_RESOURCE_1 = 0x480008;
	int ERROR_ON_STORE_RESOURCE_2 = 0x480009;

    int PIM_ATTACHMENT_COUNT_LIMIT_EXCEEDED = 0x480010;
    int PIM_ATTACHMENT_SIZE_LIMIT_EXCEEDED = 0x480011;
    int NO_DATA_PROVIDED_FOR_ATTACHMENT = 0x480012;

    int CAN_NOT_ACCESS_TEMP_FILE_FOR_ATTACHMENT_DATA = 0x480100;

}
